@@ -602,6 +602,20 @@ sub read_one_config_file {
 			$Config{'breaks'}{$a} = [ @{$Config{'breaks'}{$a}}, split(/[ \t]*,[ \t]*/,$b) ];
 			next;
 		}
+		if ($type eq "filemove") {
+			my ($b,$v) = @rest;
+			$opt_debug && print STDERR "b=$b.\n";
+			# file movement from package A to package B
+			# filemove;A;B;VERSION
+			# see https://wiki.debian.org/PackageTransition
+			# in A: breaks B (<< V)
+			# in B: breaks A (<< V)
+			#       replaces A (<< V)
+			$Config{'breaks'}{$b} = [ @{$Config{'breaks'}{$b}}, "$a (<< $v)" ];
+			$Config{'replaces'}{$b} = [ @{$Config{'replaces'}{$b}}, "$a (<< $v)" ];
+			$Config{'breaks'}{$a} = [ @{$Config{'breaks'}{$a}}, "$b (<< $v)" ];
+			next;
+		}
 		if ($type eq "execute") {
 			my ($b) = @rest;
 			$opt_debug && print STDERR  "b=$b.\n";
@@ -622,6 +636,10 @@ sub read_one_config_file {
 			push @{$TeXLive{'all'}{'kill'}}, $a;
 			next;
 		}
+		if ($type eq "notinorig") {
+			push @{$TeXLive{'all'}{'notinorig'}}, $a;
+			next;
+		}
 		if ($type eq "blacklist") {
 			if ($a eq "file") {
 				my ($b) = @rest;
